<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:nk="http://netkernel.org"
	xmlns:xrl="http://netkernel.org/xrl">
	<xsl:include href="formatIcon.xsl"/>	
	<xsl:output method="xml" omit-xml-declaration="yes" />
	<xsl:param name="panelId" nk:class="java.lang.String"/>

	<xsl:template match="/panel">
		<div>
			<xsl:variable name="widget-min">
	     		<xsl:for-each select="widgets/widget/order">
	       			<xsl:sort data-type="number" order="descending"/>
	       			<xsl:if test="position()=1"><xsl:value-of select="."/></xsl:if>
	    		 </xsl:for-each>
	   		</xsl:variable>
			<xsl:variable name="icon-min">
	     		<xsl:for-each select="icons/icon/order">
	       			<xsl:sort data-type="number" order="descending"/>
	       			<xsl:if test="position()=1"><xsl:value-of select="."/></xsl:if>
	    		 </xsl:for-each>
	   		</xsl:variable>
	   		<xsl:choose>
	   			<xsl:when test="$panelId='urn:org:netkernel:nkse:control:panel:home'">
	   				<xsl:call-template name="home"/>
	   			</xsl:when>
	   			<xsl:when test="$widget-min &gt; $icon-min">
	   				<xsl:call-template name="icons"/>
	   				<xsl:call-template name="widgets"/>
	   			</xsl:when>
	   			<xsl:otherwise>
	   				<xsl:call-template name="widgets"/>
	   				<xsl:call-template name="icons"/>
	   			</xsl:otherwise>
   			</xsl:choose>			
		</div>
	</xsl:template>
	
	<xsl:template name="home">
		<xsl:variable name="divider" select="count(icons/icon[order&lt;100])"/>
		<div class="row">
			<div class="col-sm-6">
				<xsl:apply-templates select="widgets/widget">
					<xsl:sort select="order" data-type="number" order="ascending"/>
				</xsl:apply-templates>
				<br/>
			</div>
			<div class="col-sm-6 home-panel-right" >
				<xsl:call-template name="iconColumn">
					<xsl:with-param name="start" select="0"/>
					<xsl:with-param name="end" select="$divider"/>
				</xsl:call-template>
				<br/>
				<xsl:call-template name="iconColumn">
					<xsl:with-param name="start" select="$divider+1"/>
					<xsl:with-param name="end" select="1000"/>
				</xsl:call-template>
			</div>
		</div>
	</xsl:template>		

	<xsl:template name="widgets">		
		<xsl:if test="widgets/widget">
			<xsl:apply-templates select="widgets/widget">
				<xsl:sort select="order" data-type="number" order="ascending"/>
			</xsl:apply-templates>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="icons">
		<xsl:variable name="count" select="count(icons/icon)"/>
		<xsl:variable name="half" select="ceiling($count div 2)"/>
		<div class="row">
			<div class="col-sm-6">
				<xsl:call-template name="iconColumn">
					<xsl:with-param name="start" select="1"/>
					<xsl:with-param name="end" select="$half"/>
				</xsl:call-template>
			</div>
			<div class="col-sm-6">
				<xsl:call-template name="iconColumn">
					<xsl:with-param name="start" select="$half+1"/>
					<xsl:with-param name="end" select="$count"/>
				</xsl:call-template>
			</div>
		</div>
	</xsl:template>
	
	<xsl:template name="iconColumn">
		<xsl:param name="start"/>
		<xsl:param name="end"/>
		<xsl:for-each select="icons/icon[position() &gt;= $start and position() &lt;= $end ]">
			<xsl:apply-templates select="." />
		</xsl:for-each>
	</xsl:template>

	<xsl:template match="icon">
		<div class="template-icon-block">
			<a href="{path}" class="template-lbi">
				<div style="display: table-row;">
					<div class="template-icon-title" style="float: left; display:table-cell; vertical-align:middle;">
						<xsl:call-template name="icon48"/>
					</div>
					<div style="display:table-cell; vertical-align:middle;" >
						<p class="template-icon-title">
							<xsl:value-of select="title" />
						</p>
						<p class="template-icon-subtitle">
							<xsl:value-of select="subtitle" />
						</p>
					</div>
				</div>
				 
			</a>
		</div>
	</xsl:template>

	<xsl:template match="widget">
		<div class="row">
			<div class="col-sm-12">
				<xsl:choose>
					<xsl:when test="request">
						<xrl:include>
							<xrl:identifier>
								<xsl:value-of select="request/identifier" />
							</xrl:identifier>
							<xsl:for-each select="request/argument">
								<xrl:argument>
									<xsl:attribute name="name"><xsl:value-of
										select="@name" /></xsl:attribute>
									<xsl:choose>
										<xsl:when test="*">
											<xsl:copy-of select="*" />
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="." />
										</xsl:otherwise>
									</xsl:choose>
								</xrl:argument>
							</xsl:for-each>
						</xrl:include>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="div" />
					</xsl:otherwise>
				</xsl:choose>
			</div>
		</div>
	</xsl:template>


</xsl:stylesheet>
