package org.netkernel.cp;

import java.net.URI;
import java.util.*;

import org.netkernel.layer0.boot.BootPersistence;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.nkf.INKFResponse;
import org.netkernel.layer0.representation.IBinaryStreamRepresentation;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.IReadableBinaryStreamRepresentation;
import org.netkernel.layer0.representation.impl.HDSBuilder;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;

public class CloseInfoboxAccessor extends StandardAccessorImpl
{
	private final Map<String,Boolean> mOpenState = new HashMap<String, Boolean>();
	private final Map<String,Integer> mOpenCounter = new HashMap<String, Integer>();
	private static final Integer COUNTS_TO_CLOSE=3;
	
	public void postCommission(INKFRequestContext aContext) throws Exception
	{
		IReadableBinaryStreamRepresentation rep=null;
		try
		{	rep=BootPersistence.sourceBootResource("infobox.xml", aContext.getKernelContext().getKernel());
		}
		catch (Exception e)
		{	// ignore - no saved state
		}
		if (rep!=null)
		{	IHDSNode n=aContext.transrept(rep, IHDSNode.class);
			for (Object v : n.getValues("/infobox/p"))
			{	mOpenState.put(v.toString(), Boolean.FALSE);
			}
		}
	}
	
	public void preDecommission(INKFRequestContext aContext) throws Exception
	{
		HDSBuilder b=new HDSBuilder();
		b.pushNode("infobox");
		for (Map.Entry<String, Boolean> p : mOpenState.entrySet())
		{	if (!p.getValue())
			{	b.addNode("p", p.getKey());
			}
		}
		IBinaryStreamRepresentation rep=aContext.transrept(b.getRoot(), IBinaryStreamRepresentation.class);
		BootPersistence.sinkBootResource("infobox.xml", rep, aContext.getKernelContext().getKernel());
	}
	
	
	public void onSource(INKFRequestContext aContext) throws Exception
	{	String mode=aContext.getThisRequest().getArgumentValue("mode");
		String referer=aContext.source("httpRequest:/header/Referer",String.class);
		if (referer!=null)
		{	URI refererURI=URI.create(referer);
			String refererPath=refererURI.getPath();
			//System.out.println("mode="+mode+" referer="+refererPath);
			
			if (mode.equals("IsOpen"))
			{
				boolean open=true;
				Boolean o=mOpenState.get(refererPath);
				if (o!=null)
				{	open=o;
					Integer c=mOpenCounter.get(refererPath);
					if(c!=null)
					{	if(c==0)
						{	open=false;
							mOpenState.put(refererPath, Boolean.FALSE);
							mOpenCounter.remove(refererPath);
						}
						else
						{	mOpenCounter.put(refererPath, c-1);			
						}
					}
					else
					{	mOpenCounter.put(refererPath, COUNTS_TO_CLOSE);						
					}
				}
				else
				{	mOpenState.put(refererPath, Boolean.TRUE);
					mOpenCounter.put(refererPath, COUNTS_TO_CLOSE);
				}
				INKFResponse resp=aContext.createResponseFrom("{\"o\": "+Boolean.toString(open)+"}");
				resp.setMimeType("text/json");
			}
			else if (mode.equals("Close"))
			{	mOpenState.put(refererPath, Boolean.FALSE);
				mOpenCounter.remove(refererPath);
				aContext.createResponseFrom("done");
			}
			else if (mode.equals("Open"))
			{	mOpenState.put(refererPath, Boolean.TRUE);
				mOpenCounter.put(refererPath, COUNTS_TO_CLOSE);
				aContext.createResponseFrom("done");
			}
		}
	}
	
}
