package org.netkernel.cp;

import org.netkernel.container.IKernel;
import org.netkernel.layer0.nkf.INKFLocale;
import org.netkernel.layer0.nkf.INKFRequest;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.nkf.NKFException;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.urii.SimpleIdentifierImpl;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;
import org.netkernel.request.IRequestScopeLevel;
import org.netkernel.request.impl.RequestScopeLevelImpl;
import org.netkernel.urii.IIdentifier;
import org.netkernel.urii.ISpace;
import org.netkernel.urii.impl.Version;

public class ConfigAccessor extends StandardAccessorImpl
{
	public ConfigAccessor()
	{	declareThreadSafe();
	}
	
	public void onSource(INKFRequestContext aContext) throws Exception
	{
		IHDSNode importedSpaces=aContext.source("active:SimpleImportDiscovery",IHDSNode.class);
		IKernel k=aContext.getKernelContext().getKernel();
		ControlPanelConfig config = new ControlPanelConfig();

		for (IHDSNode spaceNode: importedSpaces.getNodes("/config/space"))
		{
			IIdentifier uri=new SimpleIdentifierImpl(spaceNode.getFirstValue("uri").toString());
			Version version=new Version(spaceNode.getFirstValue("version").toString());
			ISpace space=k.getSpace(uri, version, version);
			IRequestScopeLevel scope=RequestScopeLevelImpl.createOrphanedRootScopeLevel(space, aContext.getKernelContext().getRequestScope());
			INKFRequest req=aContext.createRequest("res:/etc/system/ControlPanel.xml");
			req.setRequestScope(scope);
			try
			{	IHDSNode configNode;
				Object rep = aContext.issueRequest(req);
				if (!(rep instanceof IHDSNode))
				{	configNode=aContext.transrept(rep, IHDSNode.class);
				}
				else
				{	configNode=(IHDSNode)rep;
				}
				config.addConfig(configNode);			
			}
			catch (NKFException e)
			{	aContext.logFormatted(INKFLocale.LEVEL_WARNING, "MSG_NO_CPCONFIG", space);
			}
		}
		config.close();
		aContext.createResponseFrom(config);
		
	}
}
