package org.netkernel.cp;


import org.netkernel.ext.system.representation.IRepDeployedModules;
import org.netkernel.layer0.nkf.INKFRequest;
import org.netkernel.layer0.nkf.INKFRequestContext;
import org.netkernel.layer0.nkf.NKFException;
import org.netkernel.layer0.representation.IHDSNode;
import org.netkernel.layer0.representation.impl.HDSBuilder;
import org.netkernel.layer0.representation.impl.HDSPredicateFactory;
import org.netkernel.module.standard.endpoint.StandardAccessorImpl;
import org.netkernel.request.IRequestScopeLevel;
import org.netkernel.request.impl.RequestScopeLevelImpl;
import org.netkernel.urii.ISpace;
import org.w3c.dom.Document;

public class SearchIndexer	extends StandardAccessorImpl
{
	public void onSource(INKFRequestContext aContext) throws Exception
	{
		ControlPanelConfig config = aContext.source("active:controlPanelConfig",ControlPanelConfig.class);
		HDSBuilder b = new HDSBuilder();
		
		IRepDeployedModules dep=aContext.source("active:moduleList",IRepDeployedModules.class);
		IHDSNode hierarchy=dep.getHierarchy();
		IHDSNode cpModule=hierarchy.getNodes("/modules/module").filter(HDSPredicateFactory.namedChildStringEquals("id", "urn:org:netkernel:nkse:control:panel2")).getFirstNode();
		String wrappedSpaceHash=null;
		for (IHDSNode space: cpModule.getNodes("//space"))
		{	if (space.getFirstValue("name").toString().contains("Wrapped"))
			{	wrappedSpaceHash=space.getFirstValue("hash").toString();
			}
		}
		ISpace wrappedSpace=(ISpace)dep.componentForHash(wrappedSpaceHash);
		IRequestScopeLevel scope=RequestScopeLevelImpl.createNonDurableScopeLevel(wrappedSpace, aContext.getKernelContext().getRequestScope());
		
		for (IHDSNode panel : config.getPanels().getNodes("/panels/panel"))
		{	
			String id=(String)panel.getFirstValue("id");
			String panelName=(String)panel.getFirstValue("title");
			String panelSubtitle=(String)panel.getFirstValue("subtitle");
			String keyword=(String)panel.getFirstValue("keywords");
			index(panelName,null,panelSubtitle,"/panel/"+id,keyword,b);
			
			IHDSNode panelStuff=config.getPanel(id.trim());
			//System.out.println(panel);
			for (IHDSNode icon : panelStuff.getNodes("/panel/icons/icon"))
			{
				String title=(String)icon.getFirstValue("title");
				String desc=(String)icon.getFirstValue("subtitle");
				String docid=(String)icon.getFirstValue("path");
				keyword=(String)icon.getFirstValue("keywords");
				
				/*
				 * this doesn't work because services don't get their http params etc so often fail
				if (icon.getFirstNode("excludeFullTextIndex")==null)
				{
				
					try
					{	INKFRequest req = aContext.createRequest("res:"+docid);
						req.setRepresentationClass(Document.class);
						req.setRequestScope(scope);
						Document d=(Document)aContext.issueRequest(req);
						//Document d=aContext.source("res:"+docid, Document.class);
						System.out.println(d.getDocumentElement());
					}
					catch (NKFException e)
					{	e.printStackTrace();
					}
				}
				*/
				
				index(title,panelName,desc,docid,keyword,b);
				
			}
		}
		aContext.createResponseFrom(b.getRoot());
	}
	
	private void index(String title, String panelName, String desc, String docid, String keyword, HDSBuilder b)
	{
		b.pushNode("item");
		b.pushNode("field");
			b.addNode("@index", "NO");
			b.addNode("@store", "YES");
			b.addNode("name", "resolverID");
			b.addNode("value", "cpSearchResolver");
		b.popNode();
		b.pushNode("field");
			b.addNode("@index", "ANALYZED");
			b.addNode("@store", "YES");
			b.addNode("name", "category");
			b.addNode("value", "cp");
		b.popNode();
		b.pushNode("field");
			b.addNode("@index", "NO");
			b.addNode("@store", "YES");
			b.addNode("name", "documentID");
			b.addNode("value", docid);
		b.popNode();
		b.pushNode("field");
				b.addNode("@index", "ANALYZED");
				b.addNode("@store", "YES");
				b.addNode("name", "title");
				b.addNode("value", title);
		b.popNode();
		if (panelName!=null)
		{
			b.pushNode("field");
					b.addNode("@index", "NO");
					b.addNode("@store", "YES");
					b.addNode("name", "dtitle");
					b.addNode("value", panelName+" / "+title);
			b.popNode();
		}
		b.pushNode("field");
				b.addNode("@index", "ANALYZED");
				b.addNode("@store", "YES");
				b.addNode("name", "desc");
				b.addNode("value",desc);
			b.popNode();			
		if (keyword!=null && keyword.length()>0)
		{
			b.pushNode("field");
			b.addNode("@index", "ANALYZED");
			b.addNode("@store", "NO");
			b.addNode("name", "keywords");
			b.addNode("value",keyword);
			b.popNode();
		}
		
		b.popNode();
	}
}
